# pyeal

新的 Python 打包编译工具

包名称是python seal的意思

## 目录

- [快速开始](#快速开始)
- [功能介绍](#功能介绍)
- [版权说明](#版权说明)

### 快速开始

#### 如果你的Maya有pip那么

```commandline
pip install pyeal
python -m pyeal init
```

### 功能介绍

还在写.jpg

### 版权说明

该项目签署了Apache-2.0 授权许可，详情请参阅 LICENSE